@@ -213,10 +213,14 @@ from ncbi.datasets.openapi.model.v1_transcript_transcript_type import V1Transcri
 from ncbi.datasets.openapi.model.v1_transcript_transcript_type import V1TranscriptTranscriptType as V1alpha1TranscriptTranscriptType
 from ncbi.datasets.openapi.model.v1_version_reply import V1VersionReply
 from ncbi.datasets.openapi.model.v1_version_reply import V1VersionReply as V1alpha1VersionReply
+from ncbi.datasets.openapi.model.v1_virus_data_report_request import V1VirusDataReportRequest
+from ncbi.datasets.openapi.model.v1_virus_data_report_request import V1VirusDataReportRequest as V1alpha1VirusDataReportRequest
+from ncbi.datasets.openapi.model.v1_virus_data_report_request_content_type import V1VirusDataReportRequestContentType
+from ncbi.datasets.openapi.model.v1_virus_data_report_request_content_type import V1VirusDataReportRequestContentType as V1alpha1VirusDataReportRequestContentType
+from ncbi.datasets.openapi.model.v1_virus_dataset_filter import V1VirusDatasetFilter
+from ncbi.datasets.openapi.model.v1_virus_dataset_filter import V1VirusDatasetFilter as V1alpha1VirusDatasetFilter
 from ncbi.datasets.openapi.model.v1_virus_dataset_request import V1VirusDatasetRequest
 from ncbi.datasets.openapi.model.v1_virus_dataset_request import V1VirusDatasetRequest as V1alpha1VirusDatasetRequest
-from ncbi.datasets.openapi.model.v1_virus_dataset_request_accessions import V1VirusDatasetRequestAccessions
-from ncbi.datasets.openapi.model.v1_virus_dataset_request_accessions import V1VirusDatasetRequestAccessions as V1alpha1VirusDatasetRequestAccessions
 from ncbi.datasets.openapi.model.v1_virus_table_field import V1VirusTableField
 from ncbi.datasets.openapi.model.v1_virus_table_field import V1VirusTableField as V1alpha1VirusTableField
 from ncbi.datasets.openapi.model.v1_warning import V1Warning
@@ -241,6 +245,8 @@ from ncbi.datasets.openapi.model.v1reports_bio_sample_owner import V1reportsBioS
 from ncbi.datasets.openapi.model.v1reports_bio_sample_owner import V1reportsBioSampleOwner as V1alpha1reportsBioSampleOwner
 from ncbi.datasets.openapi.model.v1reports_bio_sample_status import V1reportsBioSampleStatus
 from ncbi.datasets.openapi.model.v1reports_bio_sample_status import V1reportsBioSampleStatus as V1alpha1reportsBioSampleStatus
+from ncbi.datasets.openapi.model.v1reports_conserved_domain import V1reportsConservedDomain
+from ncbi.datasets.openapi.model.v1reports_conserved_domain import V1reportsConservedDomain as V1alpha1reportsConservedDomain
 from ncbi.datasets.openapi.model.v1reports_gene_descriptor_gene_type import V1reportsGeneDescriptorGeneType
 from ncbi.datasets.openapi.model.v1reports_gene_descriptor_gene_type import V1reportsGeneDescriptorGeneType as V1alpha1reportsGeneDescriptorGeneType
 from ncbi.datasets.openapi.model.v1reports_gene_descriptor_rna_type import V1reportsGeneDescriptorRnaType
@@ -257,7 +263,27 @@ from ncbi.datasets.openapi.model.v1reports_prokaryote_gene_location_completeness
 from ncbi.datasets.openapi.model.v1reports_prokaryote_gene_location_completeness import V1reportsProkaryoteGeneLocationCompleteness as V1alpha1reportsProkaryoteGeneLocationCompleteness
 from ncbi.datasets.openapi.model.v1reports_purpose_of_sampling import V1reportsPurposeOfSampling
 from ncbi.datasets.openapi.model.v1reports_purpose_of_sampling import V1reportsPurposeOfSampling as V1alpha1reportsPurposeOfSampling
+from ncbi.datasets.openapi.model.v1reports_range import V1reportsRange
+from ncbi.datasets.openapi.model.v1reports_range import V1reportsRange as V1alpha1reportsRange
+from ncbi.datasets.openapi.model.v1reports_seq_range_set_fasta import V1reportsSeqRangeSetFasta
+from ncbi.datasets.openapi.model.v1reports_seq_range_set_fasta import V1reportsSeqRangeSetFasta as V1alpha1reportsSeqRangeSetFasta
 from ncbi.datasets.openapi.model.v1reports_transcript_transcript_type import V1reportsTranscriptTranscriptType
 from ncbi.datasets.openapi.model.v1reports_transcript_transcript_type import V1reportsTranscriptTranscriptType as V1alpha1reportsTranscriptTranscriptType
+from ncbi.datasets.openapi.model.v1reports_virus_annotation import V1reportsVirusAnnotation
+from ncbi.datasets.openapi.model.v1reports_virus_annotation import V1reportsVirusAnnotation as V1alpha1reportsVirusAnnotation
+from ncbi.datasets.openapi.model.v1reports_virus_assembly import V1reportsVirusAssembly
+from ncbi.datasets.openapi.model.v1reports_virus_assembly import V1reportsVirusAssembly as V1alpha1reportsVirusAssembly
+from ncbi.datasets.openapi.model.v1reports_virus_assembly_collection_location import V1reportsVirusAssemblyCollectionLocation
+from ncbi.datasets.openapi.model.v1reports_virus_assembly_collection_location import V1reportsVirusAssemblyCollectionLocation as V1alpha1reportsVirusAssemblyCollectionLocation
 from ncbi.datasets.openapi.model.v1reports_virus_assembly_completeness import V1reportsVirusAssemblyCompleteness
 from ncbi.datasets.openapi.model.v1reports_virus_assembly_completeness import V1reportsVirusAssemblyCompleteness as V1alpha1reportsVirusAssemblyCompleteness
+from ncbi.datasets.openapi.model.v1reports_virus_assembly_isolate import V1reportsVirusAssemblyIsolate
+from ncbi.datasets.openapi.model.v1reports_virus_assembly_isolate import V1reportsVirusAssemblyIsolate as V1alpha1reportsVirusAssemblyIsolate
+from ncbi.datasets.openapi.model.v1reports_virus_data_report_page import V1reportsVirusDataReportPage
+from ncbi.datasets.openapi.model.v1reports_virus_data_report_page import V1reportsVirusDataReportPage as V1alpha1reportsVirusDataReportPage
+from ncbi.datasets.openapi.model.v1reports_virus_gene import V1reportsVirusGene
+from ncbi.datasets.openapi.model.v1reports_virus_gene import V1reportsVirusGene as V1alpha1reportsVirusGene
+from ncbi.datasets.openapi.model.v1reports_virus_peptide import V1reportsVirusPeptide
+from ncbi.datasets.openapi.model.v1reports_virus_peptide import V1reportsVirusPeptide as V1alpha1reportsVirusPeptide
+from ncbi.datasets.openapi.model.v1reports_virus_peptide_uni_prot_id import V1reportsVirusPeptideUniProtId
+from ncbi.datasets.openapi.model.v1reports_virus_peptide_uni_prot_id import V1reportsVirusPeptideUniProtId as V1alpha1reportsVirusPeptideUniProtId
